.. currentmodule:: disnake_compass.impl

Emoji Parser Implementation
===========================

.. automodule:: disnake_compass.impl.parser.emoji


Classes
-------

.. attributetable:: disnake_compass.impl.parser.emoji.PartialEmojiParser

.. autoclass:: disnake_compass.impl.parser.emoji.PartialEmojiParser
    :members:

.. attributetable:: disnake_compass.impl.parser.emoji.EmojiParser

.. autoclass:: disnake_compass.impl.parser.emoji.EmojiParser
    :members:

.. attributetable:: disnake_compass.impl.parser.emoji.StickerParser

.. autoclass:: disnake_compass.impl.parser.emoji.StickerParser
    :members:
